@@ -118,15 +118,15 @@ def get_features(dataframe):
 def worker_RT(qin, qout, shift, step, RC=False, elude_path=False, ns=False, nr=False, win_sys=False):
     pepdict = dict()    
     if elude_path:
-        outtrain = tempfile.NamedTemporaryFile(suffix='.txt', mode='w')
-        outres = tempfile.NamedTemporaryFile(suffix='.txt', mode='w')
-        outres_name = outres.name
-        outres.close()
+        outtrain_name = os.path.join(tempfile.gettempdir(), os.urandom(24).hex())
+        outtrain = open(outtrain_name, 'w')
+        outres_name = os.path.join(tempfile.gettempdir(), os.urandom(24).hex())
         for seq, RT in zip(ns, nr):
             outtrain.write(seq + '\t' + str(RT) + '\n')
-        outtrain.flush()
+        outtrain.close()
 
-        outtest = tempfile.NamedTemporaryFile(suffix='.txt', mode='w')
+        outtest_name = os.path.join(tempfile.gettempdir(), os.urandom(24).hex())
+        outtest = open(outtest_name, 'w')
 
         maxval = len(qin)
         start = 0
@@ -134,14 +134,12 @@ def worker_RT(qin, qout, shift, step, RC=False, elude_path=False, ns=False, nr=F
             item = qin[start+shift]
             outtest.write(item + '\n')
             start += step
-        outtest.flush()
+        outtest.close()
 
-        subprocess.call([elude_path, '-t', outtrain.name, '-e', outtest.name, '-a', '-o', outres_name])
+        subprocess.call([elude_path, '-t', outtrain_name, '-e', outtest_name, '-a', '-o', outres_name])
         for x in open(outres_name).readlines()[3:]:
             seq, RT = x.strip().split('\t')
             pepdict[seq] = float(RT)
-        outtest.close()
-        outtrain.close()
     else:
         maxval = len(qin)
         start = 0
@@ -165,7 +163,6 @@ def final_iteration(resdict, mass_diff, rt_diff, pept_prot, protsN, base_out_nam
     pid_pep = defaultdict(set)
     banned_dict = dict()
     for pep, pid in zip(resdict['seqs'], resdict['ids']):
-    # for pep, pid in zip(resdict['seqs'], ids_array):
         
         pep_pid[pep].add(pid)
         pid_pep[pid].add(pep)
@@ -265,7 +262,7 @@ def final_iteration(resdict, mass_diff, rt_diff, pept_prot, protsN, base_out_nam
                     prots_spc_tmp[k] = all_pvals[idx]
 
                 sortedlist_spc = sorted(prots_spc_tmp.items(), key=operator.itemgetter(1))[::-1]
-                with open(base_out_name + '_proteins_full_noexclusion.csv', 'w') as output:
+                with open(base_out_name + '_proteins_full_noexclusion.tsv', 'w') as output:
                     output.write('dbname\tscore\tmatched peptides\ttheoretical peptides\n')
                     for x in sortedlist_spc:
                         output.write('\t'.join((x[0], str(x[1]), str(prots_spc_copy[x[0]]), str(protsN[x[0]]))) + '\n')
@@ -375,7 +372,7 @@ def final_iteration(resdict, mass_diff, rt_diff, pept_prot, protsN, base_out_nam
 
     prots_spc = prots_spc_final
     sortedlist_spc = sorted(prots_spc.items(), key=operator.itemgetter(1))[::-1]
-    with open(base_out_name + '_proteins_full.csv', 'w') as output:
+    with open(base_out_name + '_proteins_full.tsv', 'w') as output:
         output.write('dbname\tscore\tmatched peptides\ttheoretical peptides\n')
         for x in sortedlist_spc:
             output.write('\t'.join((x[0], str(x[1]), str(prots_spc_copy[x[0]]), str(protsN[x[0]]))) + '\n')
@@ -406,7 +403,7 @@ def final_iteration(resdict, mass_diff, rt_diff, pept_prot, protsN, base_out_nam
         print('\t'.join((str(x[0]), str(x[1]), str(int(prots_spc_copy[x[0]])), str(protsN[x[0]]))))
     print('results:%s;number of identified proteins = %d' % (base_out_name, identified_proteins, ))
     # print('R=', r)
-    with open(base_out_name + '_proteins.csv', 'w') as output:
+    with open(base_out_name + '_proteins.tsv', 'w') as output:
         output.write('dbname\tscore\tmatched peptides\ttheoretical peptides\n')
         for x in filtered_prots:
             output.write('\t'.join((x[0], str(x[1]), str(prots_spc_copy[x[0]]), str(protsN[x[0]]))) + '\n')
@@ -912,12 +909,12 @@ def process_peptides(args):
 
         if args['ts'] != 2 and deeplc_path:
 
-
-            outtrain = tempfile.NamedTemporaryFile(suffix='.txt', mode='w')
-            outcalib = tempfile.NamedTemporaryFile(suffix='.txt', mode='w')
-            outres = tempfile.NamedTemporaryFile(suffix='.txt', mode='w')
-            outres_name = outres.name
-            outres.close()
+            
+            outtrain_name = os.path.join(tempfile.gettempdir(), os.urandom(24).hex())
+            outtrain = open(outtrain_name, 'w')
+            outcalib_name = os.path.join(tempfile.gettempdir(), os.urandom(24).hex())
+            outcalib = open(outcalib_name, 'w')
+            outres_name = os.path.join(tempfile.gettempdir(), os.urandom(24).hex())
             ns = true_seqs
             nr = true_rt
             print('Peptides used for RT prediction: %d' % (len(ns), ))
@@ -928,15 +925,16 @@ def process_peptides(args):
             for seq, RT in zip(ns2, nr2):
                 mods_tmp = '|'.join([str(idx+1)+'|Carbamidomethyl' for idx, aa in enumerate(seq) if aa == 'C'])
                 outtrain.write(seq + ',' + str(mods_tmp) + ',' + str(RT) + '\n')
-            outtrain.flush()
+            outtrain.close()
 
             outcalib.write('seq,modifications,tr\n')
             for seq, RT in zip(ns, nr):
                 mods_tmp = '|'.join([str(idx+1)+'|Carbamidomethyl' for idx, aa in enumerate(seq) if aa == 'C'])
                 outcalib.write(seq + ',' + str(mods_tmp) + ',' + str(RT) + '\n')
-            outcalib.flush()
+            outcalib.close()
 
-            subprocess.call([deeplc_path, '--file_pred', outcalib.name, '--file_cal', outtrain.name, '--file_pred_out', outres_name])
+
+            subprocess.call([deeplc_path, '--file_pred', outcalib_name, '--file_cal', outtrain_name, '--file_pred_out', outres_name])
             pepdict = dict()
             train_RT = []
             train_seq = []
@@ -972,11 +970,14 @@ def process_peptides(args):
         else:
 
             if args['ts'] != 2 and elude_path:
-                outtrain = tempfile.NamedTemporaryFile(suffix='.txt', mode='w')
-                outcalib = tempfile.NamedTemporaryFile(suffix='.txt', mode='w')
-                outres = tempfile.NamedTemporaryFile(suffix='.txt', mode='w')
-                outres_name = outres.name
-                outres.close()
+
+
+                outtrain_name = os.path.join(tempfile.gettempdir(), os.urandom(24).hex())
+                outtrain = open(outtrain_name, 'w')
+                outcalib_name = os.path.join(tempfile.gettempdir(), os.urandom(24).hex())
+                outcalib = open(outcalib_name, 'w')
+                outres_name = os.path.join(tempfile.gettempdir(), os.urandom(24).hex())
+
                 ns = true_seqs
                 nr = true_rt
                 print('Peptides used for RT prediction: %d' % (len(ns), ))
@@ -984,12 +985,12 @@ def process_peptides(args):
                 nr2 = true_rt2
                 for seq, RT in zip(ns, nr):
                     outtrain.write(seq + '\t' + str(RT) + '\n')
-                outtrain.flush()
+                outtrain.close()
                 for seq, RT in zip(ns, nr):
                     outcalib.write(seq + '\t' + str(RT) + '\n')
-                outcalib.flush()
+                outcalib.close()
 
-                subprocess.call([elude_path, '-t', outtrain.name, '-e', outcalib.name, '-a', '-g', '-o', outres_name])
+                subprocess.call([elude_path, '-t', outtrain_name, '-e', outcalib_name, '-a', '-g', '-o', outres_name])
                 pepdict = dict()
                 train_RT = []
                 train_seq = []
@@ -1062,10 +1063,11 @@ def process_peptides(args):
         if deeplc_path:
 
 
-            outtrain = tempfile.NamedTemporaryFile(suffix='.txt', mode='w')
-            outres = tempfile.NamedTemporaryFile(suffix='.txt', mode='w')
-            outres_name = outres.name
-            outres.close()
+
+            outtrain_name = os.path.join(tempfile.gettempdir(), os.urandom(24).hex())
+            outtrain = open(outtrain_name, 'w')
+            outres_name = os.path.join(tempfile.gettempdir(), os.urandom(24).hex())
+
             print('Peptides used for RT prediction: %d' % (len(ns), ))
             ll = len(ns)
             ns = ns[:ll]
@@ -1075,9 +1077,9 @@ def process_peptides(args):
             for seq, RT in zip(ns, nr):
                 mods_tmp = '|'.join([str(idx+1)+'|Carbamidomethyl' for idx, aa in enumerate(seq) if aa == 'C'])
                 outtrain.write(seq + ',' + str(mods_tmp) + ',' + str(RT) + '\n')
-            outtrain.flush()
+            outtrain.close()
 
-            subprocess.call([deeplc_path, '--file_pred', outtrain.name, '--file_cal', outtrain.name, '--file_pred_out', outres_name])
+            subprocess.call([deeplc_path, '--file_pred', outtrain_name, '--file_cal', outtrain_name, '--file_pred_out', outres_name])
             pepdict = dict()
             train_RT = []
             train_seq = []
@@ -1113,19 +1115,21 @@ def process_peptides(args):
         else:
 
             if elude_path:
-                outtrain = tempfile.NamedTemporaryFile(suffix='.txt', mode='w')
-                outres = tempfile.NamedTemporaryFile(suffix='.txt', mode='w')
-                outres_name = outres.name
-                outres.close()
+
+
+                outtrain_name = os.path.join(tempfile.gettempdir(), os.urandom(24).hex())
+                outtrain = open(outtrain_name, 'w')
+                outres_name = os.path.join(tempfile.gettempdir(), os.urandom(24).hex())
+
                 print(len(ns))
                 ll = len(ns)
                 ns = ns[:ll]
                 nr = nr[:ll]
                 for seq, RT in zip(ns, nr):
                     outtrain.write(seq + '\t' + str(RT) + '\n')
-                outtrain.flush()
+                outtrain.close()
 
-                subprocess.call([elude_path, '-t', outtrain.name, '-e', outtrain.name, '-a', '-g', '-o', outres_name])
+                subprocess.call([elude_path, '-t', outtrain_name, '-e', outtrain_name, '-a', '-g', '-o', outres_name])
                 pepdict = dict()
                 train_RT = []
                 train_seq = []
@@ -1190,34 +1194,32 @@ def process_peptides(args):
 
         pepdict = dict()
 
-        outtrain = tempfile.NamedTemporaryFile(suffix='.txt', mode='w')
-        outres = tempfile.NamedTemporaryFile(suffix='.txt', mode='w')
-        outres_name = outres.name
-        outres.close()
-
+        outtrain_name = os.path.join(tempfile.gettempdir(), os.urandom(24).hex())
+        outtrain = open(outtrain_name, 'w')
+        outres_name = os.path.join(tempfile.gettempdir(), os.urandom(24).hex())
 
         outtrain.write('seq,modifications,tr\n')
         for seq, RT in zip(ns, nr):
             mods_tmp = '|'.join([str(idx+1)+'|Carbamidomethyl' for idx, aa in enumerate(seq) if aa == 'C'])
             outtrain.write(seq + ',' + str(mods_tmp) + ',' + str(RT) + '\n')
-        outtrain.flush()
+        outtrain.close()
 
-        outtest = tempfile.NamedTemporaryFile(suffix='.txt', mode='w')
+
+        outtest_name = os.path.join(tempfile.gettempdir(), os.urandom(24).hex())
+        outtest = open(outtest_name, 'w')
 
 
         outtest.write('seq,modifications\n')
         for seq in p1:
             mods_tmp = '|'.join([str(idx+1)+'|Carbamidomethyl' for idx, aa in enumerate(seq) if aa == 'C'])
             outtest.write(seq + ',' + str(mods_tmp) + '\n')
-        outtest.flush()
+        outtest.close()
 
-        subprocess.call([deeplc_path, '--file_pred', outtest.name, '--file_cal', outtrain.name, '--file_pred_out', outres_name])
+        subprocess.call([deeplc_path, '--file_pred', outtest_name, '--file_cal', outtrain_name, '--file_pred_out', outres_name])
         for x in open(outres_name).readlines()[1:]:
             _, seq, _, RT = x.strip().split(',')
             pepdict[seq] = float(RT)
 
-        outtest.close()
-        outtrain.close()
     else:
 
         if n == 1 or os.name == 'nt':
@@ -1262,12 +1264,12 @@ def process_peptides(args):
     rt_pred = rt_pred[e_ind]
 
 
-    with open(base_out_name + '_protsN.csv', 'w') as output:
+    with open(base_out_name + '_protsN.tsv', 'w') as output:
         output.write('dbname\ttheor peptides\n')
         for k, v in protsN.items():
             output.write('\t'.join((k, str(v))) + '\n')
    
-    with open(base_out_name + '_PFMs.csv', 'w') as output:
+    with open(base_out_name + '_PFMs.tsv', 'w') as output:
         output.write('sequence\tmass diff\tRT diff\tpeak_id\tIntensity\tnScans\tnIsotopes\tproteins\tm/z\tRT\taveragineCorr\tcharge\tion_mobility\n')
         # for seq, md, rtd, peak_id, I, nScans, nIsotopes, mzr, rtr, av, ch, im in zip(resdict['seqs'], resdict['md'], rt_diff, resdict['ids'], resdict['Is'], resdict['Scans'], resdict['Isotopes'], resdict['mzraw'], resdict['rt'], resdict['av'], resdict['ch'], resdict['im']):
         for seq, md, rtd, iorig in zip(resdict['seqs'], resdict['md'], rt_diff, resdict['iorig']):
@@ -1324,6 +1326,7 @@ def process_peptides(args):
             'Scans',
             'proteins',
             'peptide',
+            'md',
         }
         for feature in feature_columns:
             if feature in banned_features or feature.startswith('c_'):
@@ -1461,7 +1464,7 @@ def process_peptides(args):
         print('Features used for MachineLearning: ', get_features_pfms(df1))
 
         MAX_EVALS = 25
-        out_file = 'test_randomCV_PFMs_2.csv'
+        out_file = 'test_randomCV_PFMs_2.tsv'
         of_connection = open(out_file, 'w')
         writer = csv.writer(of_connection)
 
@@ -1510,7 +1513,7 @@ def process_peptides(args):
     df1['qpreds'] = pd.qcut(df1['preds'], 10, labels=range(10)) 
     df1['proteins'] = df1['seqs'].apply(lambda x: ';'.join(pept_prot[x]))
 
-    df1.to_csv(base_out_name + '_PFMs_ML.csv', sep='\t', index=False)
+    df1.to_csv(base_out_name + '_PFMs_ML.tsv', sep='\t', index=False)
 
     resdict['qpreds'] = df1['qpreds'].values
     resdict['ids'] = df1['ids'].values
